[vlc-commits] commit: Fix/improve some strings ( Rémi Denis-Courmont )

git at videolan.org git at videolan.org
Sun Aug 22 19:04:53 CEST 2010


vlc | branch: master | Rémi Denis-Courmont <remi at remlab.net> | Sun Aug 22 20:04:31 2010 +0300| [e621ea035d960e8e3b02bdb5af28ac3a12f77d65] | committer: Rémi Denis-Courmont 

Fix/improve some strings

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=e621ea035d960e8e3b02bdb5af28ac3a12f77d65
---

 modules/access/alsa.c     |    4 ++--
 modules/access/avio.h     |    2 +-
 modules/control/netsync.c |   12 ++++++------
 src/libvlc-module.c       |    4 ++--
 4 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/modules/access/alsa.c b/modules/access/alsa.c
index 31b7366..5f766df 100644
--- a/modules/access/alsa.c
+++ b/modules/access/alsa.c
@@ -86,8 +86,8 @@ static void DemuxClose( vlc_object_t * );
 #define CFG_PREFIX "alsa-"
 
 vlc_module_begin()
-    set_shortname( N_("Alsa") )
-    set_description( N_("Alsa audio capture input") )
+    set_shortname( N_("ALSA") )
+    set_description( N_("ALSA audio capture input") )
     set_category( CAT_INPUT )
     set_subcategory( SUBCAT_INPUT_ACCESS )
     set_help( HELP_TEXT )
diff --git a/modules/access/avio.h b/modules/access/avio.h
index 5497d34..514824b 100644
--- a/modules/access/avio.h
+++ b/modules/access/avio.h
@@ -31,7 +31,7 @@ int  OpenAvio (vlc_object_t *);
 void CloseAvio(vlc_object_t *);
 
 #define AVIO_MODULE \
-    set_shortname(N_("Avio"))               \
+    set_shortname(N_("FFmpeg"))             \
     set_description(N_("FFmpeg access") )   \
     set_category(CAT_INPUT)                 \
     set_subcategory(SUBCAT_INPUT_ACCESS)    \
diff --git a/src/libvlc-module.c b/src/libvlc-module.c
index 270b43b..810fc15 100644
--- a/src/libvlc-module.c
+++ b/src/libvlc-module.c
@@ -642,8 +642,8 @@ static const char *const ppsz_pos_descriptions[] =
 
 #define CLOCK_JITTER_TEXT N_("Clock jitter")
 #define CLOCK_JITTER_LONGTEXT N_( \
-    "It tells the clock algorithms what is the maximal input jitter that " \
-    "is considered valid and can be compensated (in milliseconds)" )
+    "This defines the maximum input delay jitter that the synchronization " \
+    "algorithms should try to compensate (in milliseconds)." )
 
 #define NETSYNC_TEXT N_("Network synchronisation" )
 #define NETSYNC_LONGTEXT N_( "This allows you to remotely " \



More information about the vlc-commits mailing list
diff --git a/modules/control/netsync.c b/modules/control/netsync.c
index 455be18..2f9e778 100644
--- a/modules/control/netsync.c
+++ b/modules/control/netsync.c
@@ -1,5 +1,5 @@
 /*****************************************************************************
  * netsync.c: synchronisation between several network clients.
  *****************************************************************************
  * Copyright (C) 2004-2009 the VideoLAN team
  * $Id$
@@ -56,20 +56,20 @@ static void Close(vlc_object_t *);
 
 #define NETSYNC_TEXT N_("Network master clock")
 #define NETSYNC_LONGTEXT N_("When set then " \
-  "this vlc instance shall dictate its clock for synchronisation" \
+  "This VLC instance shall dictate its clock for synchronization " \
   "over clients listening on the masters network ip address")
 
 #define MIP_TEXT N_("Master server ip address")
 #define MIP_LONGTEXT N_("The IP address of " \
-  "the network master clock to use for clock synchronisation.")
+  "The network master clock to use for clock synchronization.")
 
 #define NETSYNC_TIMEOUT_TEXT N_("UDP timeout (in ms)")
-#define NETSYNC_TIMEOUT_LONGTEXT N_("Amount of time (in ms) " \
-  "to wait before aborting network reception of data.")
+#define NETSYNC_TIMEOUT_LONGTEXT N_("Length of time (in ms) " \
+  "until aborting data reception.")
 
 vlc_module_begin()
     set_shortname(N_("Network Sync"))
-    set_description(N_("Network synchronisation"))
+    set_description(N_("Network synchronization"))
     set_category(CAT_ADVANCED)
     set_subcategory(SUBCAT_ADVANCED_MISC)
 
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * netsync.c: synchronisation between several network clients.
+ * netsync.c: synchronization between several network clients.
  *****************************************************************************
  * Copyright (C) 2004-2009 the VideoLAN team